@@ -1,6 +1,6 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond.model import ModelSQL, ModelView, fields, dualmethod
+from trytond.model import ModelSQL, ModelView, dualmethod, fields
 from trytond.pool import PoolMeta
 from trytond.transaction import Transaction
 
